/* x.c - Some wrappers for various functions to check and exit on out-of-memory
 *
 * Copyright © 2005 Carl Worth
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * Author: Carl Worth <carl@theworths.org>
 */

#ifndef _X_H_
#define _X_H_

#include "ttt.h"

void
xasprintf (char **strp, const char *fmt, ...) TTT_PRINTF_FORMAT(2, 3);

void
xvasprintf (char **strp, const char *fmt, va_list ap);

void
xpipe (int filedes[2]);

pid_t
xfork (void);

void *
xmalloc (size_t size);

void *
xcalloc (size_t nmemb, size_t size);

void *
xrealloc (void *ptr, size_t size);

FILE *
xfdopen (int filedes, const char *mode);

void
xfreopen (const char *path, const char *mode, FILE *stream);

char *
xstrdup (const char *s);

void
xfwrite (const void *ptr, size_t size, size_t nmemb, FILE *stream);

int
xsocket (int domain, int type, int protocol);

void
xbind (int sockfd, const struct sockaddr *my_addr, socklen_t addrlen);

ttt_status_t
xconnect (int sockfd, const struct sockaddr *serv_addr, socklen_t addrlen);

void
xlisten (int s, int backlog);

int
xfcntl (int fd, int cmd, long arg);

int
xselect (int		 n,
	 fd_set		*readfds,
	 fd_set		*writefds,
	 fd_set		*exceptfds,
	 struct timeval *timeout);

ssize_t
xread (int fd, void *buf, size_t count);

ssize_t
xwrite (int fd, const void *buf, size_t count);

#endif /* _X_H_ */
